@@ -10,6 +10,7 @@ GHCN.DAILY.COUNTRY.URL   <- "ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/ghcnd-c
 GHCN.DAILY.INVENTORY.URL <- "ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/ghcnd-inventory.txt"
 GHCN.DAILY.METADATA.URL  <- "ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/ghcnd-stations.txt"
 GHCN.DAILY.DATA.URL      <- "ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/all/"
-DAILY.DATA.DIRECTORY     <- "DailyData"
+DAILY.DATA.DIRECTORY     <- "DailyRaw"
 MONTHLY.DATA.DIRECTORY   <- "MonthlyData"
-DAILY.FILES.DIRECTORY    <- "DailyFiles"
\ No newline at end of file
+DAILY.FILES.DIRECTORY    <- "DailyFiles"
+DAILY.QA.DIRECTORY       <- "DailyData"
\ No newline at end of file
